@@ -11,6 +11,7 @@ from vi_nlp_core.ner.time_matcher import TimeMatcher
 from vi_nlp_core.ner.pername_matcher import PernameMatcher
 from vi_nlp_core.ner.gender_matcher import GenderMatcher
 from vi_nlp_core.ner.dep_matcher import DepMatcher
+from vi_nlp_core.ner.symptom_matcher import SymptomMatcher
 
 ROOT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
 NAME_PATH = os.path.join(ROOT_DIR, 'data/fullname.pkl')
@@ -36,6 +37,8 @@ class Extractor:
         self.pername_extractor = PernameMatcher(
             n_gram, NAME_PATH, SW_PATH, load_dict)
 
+        self.symptom_matcher = SymptomMatcher()
+
         self.preprocessor = Preprocess()
 
         # self.pername_extractor_deeplearning = Inference()
@@ -169,4 +172,10 @@ class Extractor:
         return self.gender_matcher.map_gender_to_key(str)
 
     def map_dep_to_key(self, str):
-        return self.dep_matcher.map_dep_to_key(str)
\ No newline at end of file
+        return self.dep_matcher.map_dep_to_key(str)
+
+    def get_department_from_symptoms(self, symptoms):
+        return self.symptom_matcher.get_department_from_symptoms(symptoms)
+
+    def extract_symptoms(self, utterance, get_dep_keys=False, top_k=3):
+        return self.symptom_matcher.extract_symptoms(utterance, get_dep_keys=get_dep_keys, top_k=top_k)
\ No newline at end of file
